@@ -34,7 +34,6 @@
 #include "gioerror.h"
 #include "glibintl.h"
 
-#include "gioalias.h"
 
 /**
  * SECTION:gmount
@@ -53,97 +52,68 @@
  * Unmounting a #GMount instance is an asynchronous operation. For
  * more information about asynchronous operations, see #GAsyncReady
  * and #GSimpleAsyncReady. To unmount a #GMount instance, first call
- * g_mount_unmount() with (at least) the #GMount instance and a
+ * g_mount_unmount_with_operation() with (at least) the #GMount instance and a
  * #GAsyncReadyCallback.  The callback will be fired when the
  * operation has resolved (either with success or failure), and a
  * #GAsyncReady structure will be passed to the callback.  That
- * callback should then call g_mount_unmount_finish() with the #GMount
+ * callback should then call g_mount_unmount_with_operation_finish() with the #GMount
  * and the #GAsyncReady data to see if the operation was completed
- * successfully.  If an @error is present when g_mount_unmount_finish() 
+ * successfully.  If an @error is present when g_mount_unmount_with_operation_finish() 
  * is called, then it will be filled with any error information.
  **/
 
-static void g_mount_base_init (gpointer g_class);
-static void g_mount_class_init (gpointer g_class,
-                                gpointer class_data);
-
-GType
-g_mount_get_type (void)
-{
-  static volatile gsize g_define_type_id__volatile = 0;
-
-  if (g_once_init_enter (&g_define_type_id__volatile))
-    {
-      const GTypeInfo mount_info =
-      {
-        sizeof (GMountIface), /* class_size */
-	g_mount_base_init,   /* base_init */
-	NULL,		/* base_finalize */
-	g_mount_class_init,
-	NULL,		/* class_finalize */
-	NULL,		/* class_data */
-	0,
-	0,              /* n_preallocs */
-	NULL
-      };
-      GType g_define_type_id =
-	g_type_register_static (G_TYPE_INTERFACE, I_("GMount"),
-				&mount_info, 0);
-
-      g_type_interface_add_prerequisite (g_define_type_id, G_TYPE_OBJECT);
-
-      g_once_init_leave (&g_define_type_id__volatile, g_define_type_id);
-    }
-
-  return g_define_type_id__volatile;
-}
+typedef GMountIface GMountInterface;
+G_DEFINE_INTERFACE (GMount, g_mount, G_TYPE_OBJECT)
 
 static void
-g_mount_class_init (gpointer g_class,
-                    gpointer class_data)
+g_mount_default_init (GMountInterface *iface)
 {
-}
+  /**
+   * GMount::changed:
+   * @mount: the object on which the signal is emitted
+   *
+   * Emitted when the mount has been changed.
+   **/
+  g_signal_new (I_("changed"),
+                G_TYPE_MOUNT,
+                G_SIGNAL_RUN_LAST,
+                G_STRUCT_OFFSET (GMountIface, changed),
+                NULL, NULL,
+                g_cclosure_marshal_VOID__VOID,
+                G_TYPE_NONE, 0);
 
-static void
-g_mount_base_init (gpointer g_class)
-{
-  static gboolean initialized = FALSE;
-
-  if (! initialized)
-    {
-     /**
-      * GMount::changed:
-      * @mount: the object on which the signal is emitted
-      * 
-      * Emitted when the mount has been changed.
-      **/
-      g_signal_new (I_("changed"),
-                    G_TYPE_MOUNT,
-                    G_SIGNAL_RUN_LAST,
-                    G_STRUCT_OFFSET (GMountIface, changed),
-                    NULL, NULL,
-                    g_cclosure_marshal_VOID__VOID,
-                    G_TYPE_NONE, 0);
-
-     /**
-      * GMount::unmounted:
-      * @mount: the object on which the signal is emitted
-      * 
-      * This signal is emitted when the #GMount have been
-      * unmounted. If the recipient is holding references to the
-      * object they should release them so the object can be
-      * finalized.
-      **/
-      g_signal_new (I_("unmounted"),
-                    G_TYPE_MOUNT,
-                    G_SIGNAL_RUN_LAST,
-                    G_STRUCT_OFFSET (GMountIface, unmounted),
-                    NULL, NULL,
-                    g_cclosure_marshal_VOID__VOID,
-                    G_TYPE_NONE, 0);
-
-      initialized = TRUE;
-    }
+  /**
+   * GMount::unmounted:
+   * @mount: the object on which the signal is emitted
+   *
+   * This signal is emitted when the #GMount have been
+   * unmounted. If the recipient is holding references to the
+   * object they should release them so the object can be
+   * finalized.
+   **/
+  g_signal_new (I_("unmounted"),
+                G_TYPE_MOUNT,
+                G_SIGNAL_RUN_LAST,
+                G_STRUCT_OFFSET (GMountIface, unmounted),
+                NULL, NULL,
+                g_cclosure_marshal_VOID__VOID,
+                G_TYPE_NONE, 0);
+  /**
+   * GMount::pre-unmount:
+   * @mount: the object on which the signal is emitted
+   *
+   * This signal is emitted when the #GMount is about to be
+   * unmounted.
+   *
+   * Since: 2.22
+   **/
+  g_signal_new (I_("pre-unmount"),
+                G_TYPE_MOUNT,
+                G_SIGNAL_RUN_LAST,
+                G_STRUCT_OFFSET (GMountIface, pre_unmount),
+                NULL, NULL,
+                g_cclosure_marshal_VOID__VOID,
+                G_TYPE_NONE, 0);
 }
 
 /**
@@ -168,6 +138,37 @@ g_mount_get_root (GMount *mount)
   return (* iface->get_root) (mount);
 }
 
+/**
+ * g_mount_get_default_location:
+ * @mount: a #GMount.
+ *
+ * Gets the default location of @mount. The default location of the given
+ * @mount is a path that reflects the main entry point for the user (e.g.
+ * the home directory, or the root of the volume).
+ *
+ * Returns: a #GFile.
+ *      The returned object should be unreffed with
+ *      g_object_unref() when no longer needed.
+ **/
+GFile *
+g_mount_get_default_location (GMount *mount)
+{
+  GMountIface *iface;
+  GFile       *file;
+
+  g_return_val_if_fail (G_IS_MOUNT (mount), NULL);
+
+  iface = G_MOUNT_GET_IFACE (mount);
+  
+  /* Fallback to get_root when default_location () is not available */
+  if (iface->get_default_location)
+    file = (* iface->get_default_location) (mount);
+  else
+    file = (* iface->get_root) (mount);
+
+  return file;
+}
+
 /**
  * g_mount_get_name:
  * @mount: a #GMount.
@@ -335,6 +336,8 @@ g_mount_can_eject (GMount *mount)
  * Unmounts a mount. This is an asynchronous operation, and is 
  * finished by calling g_mount_unmount_finish() with the @mount 
  * and #GAsyncResult data returned in the @callback.
+ *
+ * Deprecated: 2.22: Use g_mount_unmount_with_operation() instead.
  **/
 void
 g_mount_unmount (GMount              *mount,
@@ -357,7 +360,7 @@ g_mount_unmount (GMount              *mount,
 					   /* Translators: This is an error
 					    * message for mount objects that
 					    * don't implement unmount. */
-					   _("mount doesn't implement unmount"));
+					   _("mount doesn't implement \"unmount\""));
 
       return;
     }
@@ -376,6 +379,8 @@ g_mount_unmount (GMount              *mount,
  * @error will be set to contain the errors and %FALSE will be returned.
  * 
  * Returns: %TRUE if the mount was successfully unmounted. %FALSE otherwise.
+ *
+ * Deprecated: 2.22: Use g_mount_unmount_with_operation_finish() instead.
  **/
 gboolean
 g_mount_unmount_finish (GMount        *mount,
@@ -410,6 +415,8 @@ g_mount_unmount_finish (GMount        *mount,
  * Ejects a mount. This is an asynchronous operation, and is 
  * finished by calling g_mount_eject_finish() with the @mount 
  * and #GAsyncResult data returned in the @callback.
+ *
+ * Deprecated: 2.22: Use g_mount_eject_with_operation() instead.
  **/
 void
 g_mount_eject (GMount              *mount,
@@ -432,7 +439,7 @@ g_mount_eject (GMount              *mount,
 					   /* Translators: This is an error
 					    * message for mount objects that
 					    * don't implement eject. */
-					   _("mount doesn't implement eject"));
+					   _("mount doesn't implement \"eject\""));
       
       return;
     }
@@ -451,6 +458,8 @@ g_mount_eject (GMount              *mount,
  * @error will be set to contain the errors and %FALSE will be returned.
  * 
  * Returns: %TRUE if the mount was successfully ejected. %FALSE otherwise.
+ *
+ * Deprecated: 2.22: Use g_mount_eject_with_operation_finish() instead.
  **/
 gboolean
 g_mount_eject_finish (GMount        *mount,
@@ -473,6 +482,178 @@ g_mount_eject_finish (GMount        *mount,
   return (* iface->eject_finish) (mount, result, error);
 }
 
+/**
+ * g_mount_unmount_with_operation:
+ * @mount: a #GMount.
+ * @flags: flags affecting the operation
+ * @mount_operation: a #GMountOperation or %NULL to avoid user interaction.
+ * @cancellable: optional #GCancellable object, %NULL to ignore.
+ * @callback: a #GAsyncReadyCallback, or %NULL.
+ * @user_data: user data passed to @callback.
+ *
+ * Unmounts a mount. This is an asynchronous operation, and is
+ * finished by calling g_mount_unmount_with_operation_finish() with the @mount 
+ * and #GAsyncResult data returned in the @callback.
+ *
+ * Since: 2.22
+ **/
+void
+g_mount_unmount_with_operation (GMount              *mount,
+                                GMountUnmountFlags   flags,
+                                GMountOperation     *mount_operation,
+                                GCancellable        *cancellable,
+                                GAsyncReadyCallback  callback,
+                                gpointer             user_data)
+{
+  GMountIface *iface;
+
+  g_return_if_fail (G_IS_MOUNT (mount));
+
+  iface = G_MOUNT_GET_IFACE (mount);
+
+  if (iface->unmount == NULL && iface->unmount_with_operation == NULL)
+    {
+      g_simple_async_report_error_in_idle (G_OBJECT (mount),
+					   callback, user_data,
+					   G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+					   /* Translators: This is an error
+					    * message for mount objects that
+					    * don't implement any of unmount or unmount_with_operation. */
+					   _("mount doesn't implement \"unmount\" or \"unmount_with_operation\""));
+
+      return;
+    }
+
+  if (iface->unmount_with_operation != NULL)
+    (* iface->unmount_with_operation) (mount, flags, mount_operation, cancellable, callback, user_data);
+  else
+    (* iface->unmount) (mount, flags, cancellable, callback, user_data);
+}
+
+/**
+ * g_mount_unmount_with_operation_finish:
+ * @mount: a #GMount.
+ * @result: a #GAsyncResult.
+ * @error: a #GError location to store the error occuring, or %NULL to
+ *     ignore.
+ *
+ * Finishes unmounting a mount. If any errors occurred during the operation,
+ * @error will be set to contain the errors and %FALSE will be returned.
+ *
+ * Returns: %TRUE if the mount was successfully unmounted. %FALSE otherwise.
+ *
+ * Since: 2.22
+ **/
+gboolean
+g_mount_unmount_with_operation_finish (GMount        *mount,
+                                       GAsyncResult  *result,
+                                       GError       **error)
+{
+  GMountIface *iface;
+
+  g_return_val_if_fail (G_IS_MOUNT (mount), FALSE);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), FALSE);
+
+  if (G_IS_SIMPLE_ASYNC_RESULT (result))
+    {
+      GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (result);
+      if (g_simple_async_result_propagate_error (simple, error))
+        return FALSE;
+    }
+
+  iface = G_MOUNT_GET_IFACE (mount);
+  if (iface->unmount_with_operation_finish != NULL)
+    return (* iface->unmount_with_operation_finish) (mount, result, error);
+  else
+    return (* iface->unmount_finish) (mount, result, error);
+}
+
+
+/**
+ * g_mount_eject_with_operation:
+ * @mount: a #GMount.
+ * @flags: flags affecting the unmount if required for eject
+ * @mount_operation: a #GMountOperation or %NULL to avoid user interaction.
+ * @cancellable: optional #GCancellable object, %NULL to ignore.
+ * @callback: a #GAsyncReadyCallback, or %NULL.
+ * @user_data: user data passed to @callback.
+ *
+ * Ejects a mount. This is an asynchronous operation, and is
+ * finished by calling g_mount_eject_with_operation_finish() with the @mount
+ * and #GAsyncResult data returned in the @callback.
+ *
+ * Since: 2.22
+ **/
+void
+g_mount_eject_with_operation (GMount              *mount,
+                              GMountUnmountFlags   flags,
+                              GMountOperation     *mount_operation,
+                              GCancellable        *cancellable,
+                              GAsyncReadyCallback  callback,
+                              gpointer             user_data)
+{
+  GMountIface *iface;
+
+  g_return_if_fail (G_IS_MOUNT (mount));
+
+  iface = G_MOUNT_GET_IFACE (mount);
+
+  if (iface->eject == NULL && iface->eject_with_operation == NULL)
+    {
+      g_simple_async_report_error_in_idle (G_OBJECT (mount),
+					   callback, user_data,
+					   G_IO_ERROR, G_IO_ERROR_NOT_SUPPORTED,
+					   /* Translators: This is an error
+					    * message for mount objects that
+					    * don't implement any of eject or eject_with_operation. */
+					   _("mount doesn't implement \"eject\" or \"eject_with_operation\""));
+      return;
+    }
+
+  if (iface->eject_with_operation != NULL)
+    (* iface->eject_with_operation) (mount, flags, mount_operation, cancellable, callback, user_data);
+  else
+    (* iface->eject) (mount, flags, cancellable, callback, user_data);
+}
+
+/**
+ * g_mount_eject_with_operation_finish:
+ * @mount: a #GMount.
+ * @result: a #GAsyncResult.
+ * @error: a #GError location to store the error occuring, or %NULL to
+ *     ignore.
+ *
+ * Finishes ejecting a mount. If any errors occurred during the operation,
+ * @error will be set to contain the errors and %FALSE will be returned.
+ *
+ * Returns: %TRUE if the mount was successfully ejected. %FALSE otherwise.
+ *
+ * Since: 2.22
+ **/
+gboolean
+g_mount_eject_with_operation_finish (GMount        *mount,
+                                     GAsyncResult  *result,
+                                     GError       **error)
+{
+  GMountIface *iface;
+
+  g_return_val_if_fail (G_IS_MOUNT (mount), FALSE);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), FALSE);
+
+  if (G_IS_SIMPLE_ASYNC_RESULT (result))
+    {
+      GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (result);
+      if (g_simple_async_result_propagate_error (simple, error))
+        return FALSE;
+    }
+
+  iface = G_MOUNT_GET_IFACE (mount);
+  if (iface->eject_with_operation_finish != NULL)
+    return (* iface->eject_with_operation_finish) (mount, result, error);
+  else
+    return (* iface->eject_finish) (mount, result, error);
+}
+
 /**
  * g_mount_remount:
  * @mount: a #GMount.
@@ -514,7 +695,7 @@ g_mount_remount (GMount              *mount,
 					   /* Translators: This is an error
 					    * message for mount objects that
 					    * don't implement remount. */
-					   _("mount doesn't implement remount"));
+					   _("mount doesn't implement \"remount\""));
       
       return;
     }
@@ -631,14 +812,14 @@ g_mount_guess_content_type_finish (GMount        *mount,
 {
   GMountIface *iface;
 
-  g_return_val_if_fail (G_IS_MOUNT (mount), FALSE);
-  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), FALSE);
+  g_return_val_if_fail (G_IS_MOUNT (mount), NULL);
+  g_return_val_if_fail (G_IS_ASYNC_RESULT (result), NULL);
 
   if (G_IS_SIMPLE_ASYNC_RESULT (result))
     {
       GSimpleAsyncResult *simple = G_SIMPLE_ASYNC_RESULT (result);
       if (g_simple_async_result_propagate_error (simple, error))
-        return FALSE;
+        return NULL;
     }
   
   iface = G_MOUNT_GET_IFACE (mount);
@@ -828,6 +1009,3 @@ g_mount_unshadow (GMount *mount)
     g_warning ("Shadow ref count on GMount is negative");
   G_UNLOCK (priv_lock);
 }
-
-#define __G_MOUNT_C__
-#include "gioaliasdef.c"
