@@ -249,21 +249,15 @@ g_settings_real_writable_change_event (GSettings *settings,
     keys = g_settings_schema_list (settings->priv->schema, &n_keys);
 
   for (i = 0; i < n_keys; i++)
-    {
-      const gchar *string = g_quark_to_string (keys[i]);
-
-      g_signal_emit (settings, g_settings_signals[SIGNAL_WRITABLE_CHANGED],
-                     keys[i], string);
-      g_signal_emit (settings, g_settings_signals[SIGNAL_CHANGED],
-                     keys[i], string);
-    }
+    g_signal_emit (settings, g_settings_signals[SIGNAL_WRITABLE_CHANGED],
+                   keys[i], g_quark_to_string (keys[i]));
 
   return FALSE;
 }
 
 static void
-settings_backend_changed (GSettingsBackend    *backend,
-                          GObject             *target,
+settings_backend_changed (GObject             *target,
+                          GSettingsBackend    *backend,
                           const gchar         *key,
                           gpointer             origin_tag)
 {
@@ -287,8 +281,8 @@ settings_backend_changed (GSettingsBackend    *backend,
 }
 
 static void
-settings_backend_path_changed (GSettingsBackend *backend,
-                               GObject          *target,
+settings_backend_path_changed (GObject          *target,
+                               GSettingsBackend *backend,
                                const gchar      *path,
                                gpointer          origin_tag)
 {
@@ -303,8 +297,8 @@ settings_backend_path_changed (GSettingsBackend *backend,
 }
 
 static void
-settings_backend_keys_changed (GSettingsBackend    *backend,
-                               GObject             *target,
+settings_backend_keys_changed (GObject             *target,
+                               GSettingsBackend    *backend,
                                const gchar         *path,
                                const gchar * const *items,
                                gpointer             origin_tag)
@@ -347,8 +341,8 @@ settings_backend_keys_changed (GSettingsBackend    *backend,
 }
 
 static void
-settings_backend_writable_changed (GSettingsBackend *backend,
-                                   GObject          *target,
+settings_backend_writable_changed (GObject          *target,
+                                   GSettingsBackend *backend,
                                    const gchar      *key)
 {
   GSettings *settings = G_SETTINGS (target);
@@ -366,8 +360,8 @@ settings_backend_writable_changed (GSettingsBackend *backend,
 }
 
 static void
-settings_backend_path_writable_changed (GSettingsBackend *backend,
-                                        GObject          *target,
+settings_backend_path_writable_changed (GObject          *target,
+                                        GSettingsBackend *backend,
                                         const gchar      *path)
 {
   GSettings *settings = G_SETTINGS (target);
@@ -423,6 +417,10 @@ g_settings_get_property (GObject    *object,
       g_value_set_string (value, settings->priv->schema_name);
       break;
 
+     case PROP_PATH:
+      g_value_set_string (value, settings->priv->path);
+      break;
+
      case PROP_HAS_UNAPPLIED:
       g_value_set_boolean (value, g_settings_get_has_unapplied (settings));
       break;
@@ -432,6 +430,14 @@ g_settings_get_property (GObject    *object,
     }
 }
 
+static const GSettingsListenerVTable listener_vtable = {
+  settings_backend_changed,
+  settings_backend_path_changed,
+  settings_backend_keys_changed,
+  settings_backend_writable_changed,
+  settings_backend_path_writable_changed
+};
+
 static void
 g_settings_constructed (GObject *object)
 {
@@ -458,13 +464,9 @@ g_settings_constructed (GObject *object)
   if (settings->priv->backend == NULL)
     settings->priv->backend = g_settings_backend_get_default ();
 
-  g_settings_backend_watch (settings->priv->backend, G_OBJECT (settings),
-                            settings->priv->main_context,
-                            settings_backend_changed,
-                            settings_backend_path_changed,
-                            settings_backend_keys_changed,
-                            settings_backend_writable_changed,
-                            settings_backend_path_writable_changed);
+  g_settings_backend_watch (settings->priv->backend,
+                            &listener_vtable, G_OBJECT (settings),
+                            settings->priv->main_context);
   g_settings_backend_subscribe (settings->priv->backend,
                                 settings->priv->path);
 }
@@ -811,6 +813,18 @@ typedef struct
   GVariant *default_value;
 } GSettingsKeyInfo;
 
+static inline void
+endian_fixup (GVariant **value)
+{
+#if G_BYTE_ORDER == G_BIG_ENDIAN
+  GVariant *tmp;
+
+  tmp = g_variant_byteswap (*value);
+  g_variant_unref (*value);
+  *value = tmp;
+#endif
+}
+
 static void
 g_settings_get_key_info (GSettingsKeyInfo *info,
                          GSettings        *settings,
@@ -825,6 +839,7 @@ g_settings_get_key_info (GSettingsKeyInfo *info,
   iter = g_settings_schema_get_value (settings->priv->schema, key);
 
   info->default_value = g_variant_iter_next_value (iter);
+  endian_fixup (&info->default_value);
   info->type = g_variant_get_type (info->default_value);
   info->settings = g_object_ref (settings);
   info->key = g_intern_string (key);
@@ -857,6 +872,8 @@ g_settings_get_key_info (GSettingsKeyInfo *info,
 
         case 'r':
           g_variant_get (data, "(**)", &info->minimum, &info->maximum);
+          endian_fixup (&info->minimum);
+          endian_fixup (&info->maximum);
           break;
 
         default:
@@ -1908,13 +1925,9 @@ g_settings_delay (GSettings *settings)
   g_object_unref (settings->priv->backend);
 
   settings->priv->backend = G_SETTINGS_BACKEND (settings->priv->delayed);
-  g_settings_backend_watch (settings->priv->backend, G_OBJECT (settings),
-                            settings->priv->main_context,
-                            settings_backend_changed,
-                            settings_backend_path_changed,
-                            settings_backend_keys_changed,
-                            settings_backend_writable_changed,
-                            settings_backend_path_writable_changed);
+  g_settings_backend_watch (settings->priv->backend,
+                            &listener_vtable, G_OBJECT (settings),
+                            settings->priv->main_context);
 }
 
 /**
@@ -1981,7 +1994,7 @@ g_settings_get_has_unapplied (GSettings *settings)
            G_DELAYED_SETTINGS_BACKEND (settings->priv->backend));
 }
 
-/* Extra API (reset, sync, get_child, is_writable, list_items) {{{1 */
+/* Extra API (reset, sync, get_child, is_writable, list_*) {{{1 */
 /**
  * g_settings_reset:
  * @settings: a #GSettings object
@@ -2096,36 +2109,90 @@ g_settings_get_child (GSettings   *settings,
 }
 
 /**
- * g_settings_list_items:
+ * g_settings_list_keys:
  * @settings: a #GSettings object
  * @returns: a list of the keys on @settings
  *
- * Introspects the list of keys and children on @settings.
- *
- * The list that is returned is a mix of the keys and children.  The
- * names of the children are suffixed with '/'.  The names of the keys
- * are not.
+ * Introspects the list of keys on @settings.
  *
  * You should probably not be calling this function from "normal" code
  * (since you should already know what keys are in your schema).  This
  * function is intended for introspection reasons.
  *
- * You should free the return value with g_free() when you are done with
- * it.
+ * You should free the return value with g_strfreev() when you are done
+ * with it.
  */
-const gchar **
-g_settings_list_items (GSettings *settings)
+gchar **
+g_settings_list_keys (GSettings *settings)
 {
   const GQuark *keys;
-  const gchar **strv;
+  gchar **strv;
   gint n_keys;
-  gint i;
+  gint i, j;
 
   keys = g_settings_schema_list (settings->priv->schema, &n_keys);
-  strv = g_new (const gchar *, n_keys + 1);
-  for (i = 0; i < n_keys; i++)
-    strv[i] = g_quark_to_string (keys[i]);
-  strv[i] = NULL;
+  strv = g_new (gchar *, n_keys + 1);
+  for (i = j = 0; i < n_keys; i++)
+    {
+      const gchar *key = g_quark_to_string (keys[i]);
+
+      if (!g_str_has_suffix (key, "/"))
+        strv[j++] = g_strdup (key);
+    }
+  strv[j] = NULL;
+
+  return strv;
+}
+
+/**
+ * g_settings_list_children:
+ * @settings: a #GSettings object
+ * @returns: a list of the children on @settings
+ *
+ * Gets the list of children on @settings.
+ *
+ * The list is exactly the list of strings for which it is not an error
+ * to call g_settings_get_child().
+ *
+ * For GSettings objects that are lists, this value can change at any
+ * time and you should connect to the "children-changed" signal to watch
+ * for those changes.  Note that there is a race condition here: you may
+ * request a child after listing it only for it to have been destroyed
+ * in the meantime.  For this reason, g_settings_get_chuld() may return
+ * %NULL even for a child that was listed by this function.
+ *
+ * For GSettings objects that are not lists, you should probably not be
+ * calling this function from "normal" code (since you should already
+ * know what children are in your schema).  This function may still be
+ * useful there for introspection reasons, however.
+ *
+ * You should free the return value with g_strfreev() when you are done
+ * with it.
+ */
+gchar **
+g_settings_list_children (GSettings *settings)
+{
+  const GQuark *keys;
+  gchar **strv;
+  gint n_keys;
+  gint i, j;
+
+  keys = g_settings_schema_list (settings->priv->schema, &n_keys);
+  strv = g_new (gchar *, n_keys + 1);
+  for (i = j = 0; i < n_keys; i++)
+    {
+      const gchar *key = g_quark_to_string (keys[i]);
+
+      if (g_str_has_suffix (key, "/"))
+        {
+          gint length = strlen (key);
+
+          strv[j] = g_memdup (key, length);
+          strv[j][length - 1] = '\0';
+          j++;
+        }
+    }
+  strv[j] = NULL;
 
   return strv;
 }
