@@ -27,6 +27,7 @@ test_basic (void)
 
   g_object_get (settings, "schema", &str, NULL);
   g_assert_cmpstr (str, ==, "org.gtk.test");
+  g_free (str);
 
   g_settings_get (settings, "greeting", "s", &str);
   g_assert_cmpstr (str, ==, "Hello, earthlings");
@@ -55,6 +56,11 @@ test_basic (void)
   g_free (str);
   str = NULL;
 
+  g_settings_reset (settings, "greeting");
+  str = g_settings_get_string (settings, "greeting");
+  g_assert_cmpstr (str, ==, "Hello, earthlings");
+  g_free (str);
+
   g_settings_set (settings, "greeting", "s", "this is the end");
   g_object_unref (settings);
 }
@@ -676,6 +682,7 @@ enum
 {
   PROP_0,
   PROP_BOOL,
+  PROP_ANTI_BOOL,
   PROP_BYTE,
   PROP_INT16,
   PROP_UINT16,
@@ -687,6 +694,7 @@ enum
   PROP_STRING,
   PROP_NO_READ,
   PROP_NO_WRITE,
+  PROP_STRV,
   PROP_ENUM
 };
 
@@ -695,6 +703,7 @@ typedef struct
   GObject parent_instance;
 
   gboolean bool_prop;
+  gboolean anti_bool_prop;
   gchar byte_prop;
   gint int16_prop;
   guint16 uint16_prop;
@@ -706,6 +715,7 @@ typedef struct
   gchar *string_prop;
   gchar *no_read_prop;
   gchar *no_write_prop;
+  gchar **strv_prop;
   guint enum_prop;
 } TestObject;
 
@@ -725,6 +735,7 @@ static void
 test_object_finalize (GObject *object)
 {
   TestObject *testo = (TestObject*)object;
+  g_strfreev (testo->strv_prop);
   g_free (testo->string_prop);
   G_OBJECT_CLASS (test_object_parent_class)->finalize (object);
 }
@@ -742,6 +753,9 @@ test_object_get_property (GObject    *object,
     case PROP_BOOL:
       g_value_set_boolean (value, test_object->bool_prop);
       break;
+    case PROP_ANTI_BOOL:
+      g_value_set_boolean (value, test_object->anti_bool_prop);
+      break;
     case PROP_BYTE:
       g_value_set_char (value, test_object->byte_prop);
       break;
@@ -772,6 +786,9 @@ test_object_get_property (GObject    *object,
     case PROP_NO_WRITE:
       g_value_set_string (value, test_object->no_write_prop);
       break;
+    case PROP_STRV:
+      g_value_set_boxed (value, test_object->strv_prop);
+      break;
     case PROP_ENUM:
       g_value_set_enum (value, test_object->enum_prop);
       break;
@@ -794,6 +811,9 @@ test_object_set_property (GObject      *object,
     case PROP_BOOL:
       test_object->bool_prop = g_value_get_boolean (value);
       break;
+    case PROP_ANTI_BOOL:
+      test_object->anti_bool_prop = g_value_get_boolean (value);
+      break;
     case PROP_BYTE:
       test_object->byte_prop = g_value_get_char (value);
       break;
@@ -826,6 +846,10 @@ test_object_set_property (GObject      *object,
       g_free (test_object->no_read_prop);
       test_object->no_read_prop = g_value_dup_string (value);
       break;
+    case PROP_STRV:
+      g_strfreev (test_object->strv_prop);
+      test_object->strv_prop = g_value_dup_boxed (value);
+      break;
     case PROP_ENUM:
       test_object->enum_prop = g_value_get_enum (value);
       break;
@@ -868,6 +892,8 @@ test_object_class_init (TestObjectClass *class)
 
   g_object_class_install_property (gobject_class, PROP_BOOL,
     g_param_spec_boolean ("bool", "", "", FALSE, G_PARAM_READWRITE));
+  g_object_class_install_property (gobject_class, PROP_ANTI_BOOL,
+    g_param_spec_boolean ("anti-bool", "", "", FALSE, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_BYTE,
     g_param_spec_char ("byte", "", "", G_MININT8, G_MAXINT8, 0, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_INT16,
@@ -890,6 +916,8 @@ test_object_class_init (TestObjectClass *class)
     g_param_spec_string ("no-write", "", "", NULL, G_PARAM_READABLE));
   g_object_class_install_property (gobject_class, PROP_NO_READ,
     g_param_spec_string ("no-read", "", "", NULL, G_PARAM_WRITABLE));
+  g_object_class_install_property (gobject_class, PROP_STRV,
+    g_param_spec_boxed ("strv", "", "", G_TYPE_STRV, G_PARAM_READWRITE));
   g_object_class_install_property (gobject_class, PROP_ENUM,
     g_param_spec_enum ("enum", "", "", test_enum_get_type (), TEST_ENUM_FOO, G_PARAM_READWRITE));
 }
@@ -914,17 +942,19 @@ test_simple_binding (void)
   gint i;
   gint16 n;
   guint16 q;
+  gint n2;
+  guint q2;
   gint64 i64;
   guint64 u64;
   gdouble d;
   gchar *s;
   GVariant *value;
+  gchar **strv;
 
   settings = g_settings_new ("org.gtk.test.binding");
   obj = test_object_new ();
 
   g_settings_bind (settings, "bool", obj, "bool", G_SETTINGS_BIND_DEFAULT);
-
   g_object_set (obj, "bool", TRUE, NULL);
   g_assert_cmpint (g_settings_get_boolean (settings, "bool"), ==, TRUE);
 
@@ -933,6 +963,16 @@ test_simple_binding (void)
   g_object_get (obj, "bool", &b, NULL);
   g_assert_cmpint (b, ==, FALSE);
 
+  g_settings_bind (settings, "anti-bool", obj, "anti-bool",
+                   G_SETTINGS_BIND_INVERT_BOOLEAN);
+  g_object_set (obj, "anti-bool", FALSE, NULL);
+  g_assert_cmpint (g_settings_get_boolean (settings, "anti-bool"), ==, TRUE);
+
+  g_settings_set_boolean (settings, "anti-bool", FALSE);
+  b = FALSE;
+  g_object_get (obj, "anti-bool", &b, NULL);
+  g_assert_cmpint (b, ==, TRUE);
+
   g_settings_bind (settings, "byte", obj, "byte", G_SETTINGS_BIND_DEFAULT);
 
   g_object_set (obj, "byte", 123, NULL);
@@ -953,9 +993,9 @@ test_simple_binding (void)
   g_assert_cmpint (n, ==, 1234);
 
   g_settings_set (settings, "int16", "n", 4321);
-  n = 1111;
-  g_object_get (obj, "int16", &n, NULL);
-  g_assert_cmpint (n, ==, 4321);
+  n2 = 1111;
+  g_object_get (obj, "int16", &n2, NULL);
+  g_assert_cmpint (n2, ==, 4321);
 
   g_settings_bind (settings, "uint16", obj, "uint16", G_SETTINGS_BIND_DEFAULT);
 
@@ -965,9 +1005,9 @@ test_simple_binding (void)
   g_assert_cmpuint (q, ==, G_MAXUINT16);
 
   g_settings_set (settings, "uint16", "q", (guint16) G_MAXINT16);
-  q = 1111;
-  g_object_get (obj, "uint16", &q, NULL);
-  g_assert_cmpuint (q, ==, (guint16) G_MAXINT16);
+  q2 = 1111;
+  g_object_get (obj, "uint16", &q2, NULL);
+  g_assert_cmpuint (q2, ==, (guint16) G_MAXINT16);
 
   g_settings_bind (settings, "int", obj, "int", G_SETTINGS_BIND_DEFAULT);
 
@@ -1040,9 +1080,29 @@ test_simple_binding (void)
   g_object_get (obj, "double", &d, NULL);
   g_assert_cmpfloat (d, ==, -G_MINDOUBLE);
 
+  strv = g_strsplit ("plastic bag,middle class,polyethylene", ",", 0);
+  g_settings_bind (settings, "strv", obj, "strv", G_SETTINGS_BIND_DEFAULT);
+  g_object_set (obj, "strv", strv, NULL);
+  g_strfreev (strv);
+  strv = g_settings_get_strv (settings, "strv");
+  s = g_strjoinv (",", strv);
+  g_assert_cmpstr (s, ==, "plastic bag,middle class,polyethylene");
+  g_strfreev (strv);
+  g_free (s);
+  strv = g_strsplit ("decaffeinate,unleaded,keep all surfaces clean", ",", 0);
+  g_settings_set_strv (settings, "strv", (const gchar **) strv);
+  g_strfreev (strv);
+  g_object_get (obj, "strv", &strv, NULL);
+  s = g_strjoinv (",", strv);
+  g_assert_cmpstr (s, ==, "decaffeinate,unleaded,keep all surfaces clean");
+  g_strfreev (strv);
+  g_free (s);
+
   g_settings_bind (settings, "enum", obj, "enum", G_SETTINGS_BIND_DEFAULT);
   g_object_set (obj, "enum", TEST_ENUM_BAZ, NULL);
-  g_assert_cmpstr (g_settings_get_string (settings, "enum"), ==, "baz");
+  s = g_settings_get_string (settings, "enum");
+  g_assert_cmpstr (s, ==, "baz");
+  g_free (s);
   g_assert_cmpint (g_settings_get_enum (settings, "enum"), ==, TEST_ENUM_BAZ);
 
   g_settings_set_enum (settings, "enum", TEST_ENUM_QUUX);
@@ -1639,7 +1699,7 @@ test_range (void)
 }
 
 static gboolean
-strv_has_string (const gchar **haystack,
+strv_has_string (gchar       **haystack,
                  const gchar  *needle)
 {
   guint n;
@@ -1653,7 +1713,7 @@ strv_has_string (const gchar **haystack,
 }
 
 static gboolean
-strv_set_equal (const gchar **strv, ...)
+strv_set_equal (gchar **strv, ...)
 {
   gint count;
   va_list list;
@@ -1687,18 +1747,44 @@ static void
 test_list_items (void)
 {
   GSettings *settings;
-  const gchar **items;
+  gchar **children;
+  gchar **keys;
 
   settings = g_settings_new ("org.gtk.test");
-  items = g_settings_list_items (settings);
+  children = g_settings_list_children (settings);
+  keys = g_settings_list_keys (settings);
 
-  g_assert (strv_set_equal (items, "greeting", "farewell", "basic-types/", "complex-types/", "localized/", NULL));
+  g_assert (strv_set_equal (children, "basic-types", "complex-types", "localized", NULL));
+  g_assert (strv_set_equal (keys, "greeting", "farewell", NULL));
 
-  g_free (items);
+  g_strfreev (children);
+  g_strfreev (keys);
 
   g_object_unref (settings);
 }
 
+static void
+test_list_schemas (void)
+{
+  const gchar * const *schemas;
+
+  schemas = g_settings_list_schemas ();
+
+  g_assert (strv_set_equal ((gchar **)schemas,
+                            "org.gtk.test",
+                            "org.gtk.test.no-path",
+                            "org.gtk.test.basic-types",
+                            "org.gtk.test.complex-types",
+                            "org.gtk.test.localized",
+                            "org.gtk.test.binding",
+                            "org.gtk.test.enums",
+                            "org.gtk.test.enums.direct",
+                            "org.gtk.test.range",
+                            "org.gtk.test.range.direct",
+                            "org.gtk.test.mapped",
+                            NULL));
+}
+
 static gboolean
 map_func (GVariant *value,
           gpointer *result,
@@ -1762,6 +1848,7 @@ main (int argc, char *argv[])
 
   backend_set = g_getenv ("GSETTINGS_BACKEND") != NULL;
 
+  g_setenv ("XDG_DATA_DIRS", ".", TRUE);
   g_setenv ("GSETTINGS_SCHEMA_DIR", ".", TRUE);
 
   if (!backend_set)
@@ -1832,6 +1919,7 @@ main (int argc, char *argv[])
   g_test_add_func ("/gsettings/flags", test_flags);
   g_test_add_func ("/gsettings/range", test_range);
   g_test_add_func ("/gsettings/list-items", test_list_items);
+  g_test_add_func ("/gsettings/list-schemas", test_list_schemas);
   g_test_add_func ("/gsettings/mapped", test_get_mapped);
 
   result = g_test_run ();
