@@ -23,10 +23,10 @@
  * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GLib Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GLib at ftp://ftp.gtk.org/pub/gtk/. 
+ * GLib at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-/* 
+/*
  * MT safe ; except for g_data*_foreach()
  */
 
@@ -34,8 +34,14 @@
 
 #include <string.h>
 
-#include "glib.h"
+#include "gdataset.h"
+
 #include "gdatasetprivate.h"
+#include "ghash.h"
+#include "gquark.h"
+#include "gstrfuncs.h"
+#include "gtestutils.h"
+#include "gthread.h"
 #include "glib_trace.h"
 
 /**
@@ -994,8 +1000,10 @@ GQuark
 g_quark_try_string (const gchar *string)
 {
   GQuark quark = 0;
-  g_return_val_if_fail (string != NULL, 0);
-  
+
+  if (string == NULL)
+    return 0;
+
   G_LOCK (g_quark_global);
   if (g_quark_ht)
     quark = GPOINTER_TO_UINT (g_hash_table_lookup (g_quark_ht, string));
