@@ -21,10 +21,10 @@
  * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GLib Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GLib at ftp://ftp.gtk.org/pub/gtk/. 
+ * GLib at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-/* 
+/*
  * MT safe
  */
 
@@ -39,10 +39,10 @@
 #include <string.h>
 #include <ctype.h>
 
-#include "glib.h"
+#include "gstring.h"
+
 #include "gprintf.h"
 
-#include "galias.h"
 
 /**
  * SECTION: string_chunks
@@ -1519,6 +1519,3 @@ g_string_append_printf (GString     *string,
   g_string_append_vprintf (string, format, args);
   va_end (args);
 }
-
-#define __G_STRING_C__
-#include "galiasdef.c"
